OC.L10N.register(
    "settings",
    {
    "Migration in progress. Please wait until the migration is finished" : "Immigration er i gang. Vent venligst indtil overflytningen er afsluttet",
    "Migration started …" : "Migrering er påbegyndt...",
    "Saved" : "Gemt",
    "Not saved" : "Ikke gemt",
    "Sending…" : "Sender...",
    "Email sent" : "E-mail afsendt",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Der opstod en fejl. Upload venligst et ASCII-indkodet PEM-certifikat.",
    "Valid until {date}" : "Gyldig indtil {date}",
    "Delete" : "Slet",
    "Local" : "Lokal",
    "Private" : "Privat",
    "Only visible to local users" : "Kun synlig for lokale brugere",
    "Only visible to you" : "Kun synlig for dig",
    "Contacts" : "Kontakter",
    "Public" : "Offentlig",
    "Verify" : "Bekræft",
    "Verifying …" : "Bekræfter.....",
    "Unable to change password" : "Kunne ikke ændre kodeord",
    "Very weak password" : "Meget svagt kodeord",
    "Weak password" : "Svagt kodeord",
    "So-so password" : "Jævnt kodeord",
    "Good password" : "Godt kodeord",
    "Strong password" : "Stærkt kodeord",
    "Select a profile picture" : "Vælg et profilbillede",
    "Week starts on {fdow}" : "Ugen starter {fdow}",
    "Groups" : "Grupper",
    "Group list is empty" : "Tom gruppeliste",
    "{actor} added you to group {group}" : "{actor} tilføjede dig til gruppe {group}",
    "You added {user} to group {group}" : "Tilføjede {user} til gruppen {group}",
    "{actor} added {user} to group {group}" : "{actor} tilføjede {user} til gruppe {group}",
    "An administrator added you to group {group}" : "En administrator tilføjede dig til gruppen {group}",
    "An administrator added {user} to group {group}" : "En administrator tilføjede {user} til gruppen {group}",
    "{actor} removed you from group {group}" : "{actor} fjernede dig fra gruppen {group}",
    "You removed {user} from group {group}" : "Fjernede {user}  fra gruppen {group}",
    "{actor} removed {user} from group {group}" : "{actor} fjernede {user}fra gruppen {group}",
    "An administrator removed you from group {group}" : "En administrator fjernede dig fra gruppen {group}",
    "An administrator removed {user} from group {group}" : "En administrator fjernede {user} fra gruppen {group}",
    "Your <strong>group memberships</strong> were modified" : "Dine <strong>gruppemedlemsskaber</strong> blev ændret",
    "{actor} changed your password" : "{actor} ændrede din adgangskode",
    "You changed your password" : "Du ændrede din kode",
    "Your password was reset by an administrator" : "Din adgangskode er blevet resat af en administrator",
    "{actor} changed your email address" : "{actor} skiftede din e-mail adresse",
    "You changed your email address" : "Du har ændret din email adresse",
    "Your email address was changed by an administrator" : "Din email adresse er blevet ændret af en administrator",
    "Security" : "Sikkerhed",
    "You successfully logged in using two-factor authentication (%1$s)" : "Du loggede in ved at bruge two-factor authentication (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Et login forsøg mislykkedes med two-factor authentication (%1$s)",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Dit <strong>password</strong> eller <strong>email</strong> blev ændret",
    "Couldn't remove app." : "Kunne ikke fjerne app'en.",
    "Couldn't update app." : "Kunne ikke opdatere app'en.",
    "Wrong password" : "Forkert kodeord",
    "No user supplied" : "Intet brugernavn givet",
    "Authentication error" : "Adgangsfejl",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Angiv venligst en administrator gendannelseskode, ellers vil alt brugerdata gå tabt",
    "Wrong admin recovery password. Please check the password and try again." : "Forkert admin gendannelseskode. Se venligst koden efter og prøv igen.",
    "Backend doesn't support password change, but the user's encryption key was updated." : "Backend'en understøtter ikke skift af kodeord, men opdateringen af brugerens krypteringsnøgle blev gennemført.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "installation og opdatering af apps via app-butikken eller sammensluttet Cloud deling",
    "Federated Cloud Sharing" : "Sammensluttet Cloud deling",
    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL bruger en forældet %1$s version (%2$s). Du skal opdatere dit styresystem for at funktioner som %3$s virker pålideligt.",
    "Invalid SMTP password." : "Ikke gyldigt SMTP password",
    "Email setting test" : "Test email-indstillinger",
    "Well done, %s!" : "Godt gået, %s!",
    "If you received this email, the email configuration seems to be correct." : "Hvis du har modtaget denne email, så er email konfigureret rigtigt.",
    "Email could not be sent. Check your mail server log" : "Email kunne ikke sendes. Tjek din mail server log",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Der opstod et problem under afsendelse af e-mailen. Gennemse venligst dine indstillinger. (Fejl: %s)",
    "You need to set your user email before being able to send test emails." : "Du skal angive din bruger-e-mail før der kan sendes test-e-mail.",
    "Invalid mail address" : "Ugyldig mailadresse",
    "Settings saved" : "Indstillinger gemt",
    "Unable to change full name" : "Ikke i stand til at ændre dit fulde navn",
    "Unable to change email address" : "Kan ikke ændre emailadressen",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "For at verificerer din Twitter konto, post den følgende tweet på Twitter (Sørg for at poste det uden linjeskift)",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "For at bekræfte din hjemmeside, opbevare følgende indhold i din web-roden '.well-known/CloudIdVerificationCode.txt' \n(vær sikker på, at den fulde tekst er på en linje):",
    "%1$s changed your password on %2$s." : "%1$s ændrede dit password på %2$s.",
    "Your password on %s was changed." : "Dit password på %s blev ændret.",
    "Your password on %s was reset by an administrator." : "Dit password på %s er blevet nulstillet af en administrator.",
    "Password for %1$s changed on %2$s" : "Password for %1$s er ændret på %2$s",
    "Password changed for %s" : "Password ændret for %s",
    "If you did not request this, please contact an administrator." : "Kontakt en administrator, hvis du ikke har bedt om dette.",
    "Your email address on %s was changed." : "Din email på %s blev ændret.",
    "Your email address on %s was changed by an administrator." : "Din email adresse på %s er blevet ændret af en administrator",
    "Email address for %1$s changed on %2$s" : "Email adresse for %1$s ændret på %2$s",
    "Email address changed for %s" : "Email adresse ændret for %s",
    "The new email address is %s" : "Den nye email adresse er %s",
    "Your %s account was created" : "Din %s-konto blev oprettet",
    "Welcome aboard" : "Velkommen ombord",
    "Welcome aboard %s" : "velkommen ombord %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Velkommen til din %s konto, du kan tilføje, beskytte og dele dine data.",
    "Your username is: %s" : "Dit brugernavn er: %s",
    "Set your password" : "Sæt dit password",
    "Go to %s" : "Gå til %s",
    "Install Client" : "Installer client",
    "Create" : "Opret",
    "Unlimited" : "Ubegrænset",
    "Limit to groups" : "Begræns til grupper",
    "Excluded groups" : "Ekskluderede grupper",
    "Save changes" : "Gem ændringer",
    "Official" : "Officiel",
    "by" : "af",
    "Update to {version}" : "Opdateret til {version}",
    "Remove" : "Fjern",
    "Disable" : "Deaktiver",
    "All" : "Alle",
    "No results" : "Ingen resultater",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Denne app har ikke angivet en mindste understøttede version af Nextcloud. I fremtiden vil det være en fejl.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Denne app har ikke angivet en højeste understøttede version af Nextcloud. I fremtiden vil det være en fejl.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Dette program kan ikke installeres, da følgende afhængigheder ikke imødekommes:",
    "View in store" : "Se i butik",
    "Visit website" : "Besøg hjemmeside",
    "Report a bug" : "Rapporter en fejl",
    "User documentation" : "Brugerdokumentation",
    "Admin documentation" : "Admin-dokumentation",
    "Developer documentation" : "Dokumentation for udviklere",
    "Update to {update}" : "Opdater til {update}",
    "No apps found for your version" : "Ingen apps fundet til din verion",
    "Enable all" : "Aktiver alle",
    "Download and enable" : "Download og aktiver",
    "Enable" : "Aktiver",
    "The app will be downloaded from the app store" : "Appen vil blive downloaded fra app storen.",
    "Device settings" : "Enhedsindstillinger",
    "Allow filesystem access" : "Tillad filsystem adgang",
    "Revoke" : "Tilbagekald",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome til Android",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "Nextcloud iOS app" : "Nextcloud iOS app",
    "Nextcloud Android app" : "Nextcloud Android app",
    "Nextcloud Talk for iOS" : "Nextcloud Talk til iOS",
    "Nextcloud Talk for Android" : "Nextcloud Talk til Android",
    "Sync client - {os}" : "Synk klient - {os}",
    "This session" : "Sessionen",
    "Device" : "Enhed",
    "Last activity" : "Sidste aktivitet",
    "Devices & sessions" : "Enheder og sessioner",
    "Web, desktop and mobile clients currently logged in to your account." : "Web, stationære og mobile klienter, der er logget ind på din konto.",
    "Error while creating device token" : "Fejl ved oprettelse af enhedsnøgle",
    "Error while deleting the token" : "Fejl ved sletning af enhedsnøgle",
    "App name" : "App navn",
    "Create new app password" : "Opret nyt app kodeord",
    "Username" : "Brugernavn",
    "Password" : "Kodeord",
    "Done" : "Færdig",
    "Copied!" : "Kopieret",
    "Copy" : "Kopier",
    "New password" : "Nyt kodeord",
    "Add user in group" : "Tilføj bruger i gruppe",
    "Set user as admin for" : "Gør bruger til administrator for",
    "Select user quota" : "Vælg brugerkvote",
    "Never" : "Aldrig",
    "Delete user" : "Slet bruger",
    "Disable user" : "Deaktiver bruger",
    "Enable user" : "Aktiver bruger",
    "Resend welcome email" : "Send velkomstemail igen",
    "{size} used" : "{size} brugt",
    "Welcome mail sent!" : "Velkomstemail sendt!",
    "Display name" : "Vist navn",
    "Email" : "E-mail",
    "Group admin for" : "Gruppeadministrator for",
    "Quota" : "Kvote",
    "Language" : "Sprog",
    "Storage location" : "Placering af lageret",
    "User backend" : "Bruger-backend",
    "Last login" : "Seneste login",
    "Default language" : "Standardsprog",
    "Add a new user" : "Tilføj en bruger",
    "No users in here" : "Ingen brugere her",
    "Default quota" : "Standard kvote",
    "Common languages" : "Hyppigt brugte sprog",
    "All languages" : "Alle sprog",
    "Your apps" : "Dine apps",
    "Active apps" : "Aktive apps",
    "Disabled apps" : "Deaktiverede apps",
    "Updates" : "Opdateringer",
    "App bundles" : "App bundles",
    "New user" : "Ny bruger",
    "Default quota:" : "Standardkvote:",
    "Select default quota" : "Vælg standardkvote",
    "Show Languages" : "Vis sprog",
    "Show last login" : "Vis seneste login",
    "Show user backend" : "Vis bruger-backend",
    "Remove group" : "Fjern gruppe",
    "Admins" : "Administratore",
    "Disabled users" : "Deaktiverede brugere",
    "Everyone" : "Alle",
    "Add group" : "Tilføj gruppe",
    "You are about to remove the group {group}. The users will NOT be deleted." : "Du er ved at fjerne gruppen {group}. Brugerne bliver IKKE slettet.",
    "Please confirm the group removal " : "Bekræft at gruppen skal fjernes",
    "App update" : "App opdatering",
    "Error: This app can not be enabled because it makes the server unstable" : "Fejl: Denne app kan ikke aktiveres fordi den gør serveren ustabil",
    "SSL Root Certificates" : "SSL rodcertifikater",
    "Common Name" : "Almindeligt navn",
    "Valid until" : "Gyldig indtil",
    "Issued By" : "Udstedt af",
    "Valid until %s" : "Gyldig indtil %s",
    "Import root certificate" : "Importer rodcertifikat",
    "Administrator documentation" : "Administratordokumentation",
    "Documentation" : "Dokumentation",
    "Forum" : "Forum",
    "None" : "Ingen",
    "Login" : "Login",
    "Plain" : "Klartekst",
    "NT LAN Manager" : "NT LAN Manager",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "E-mailserver",
    "Open documentation" : "Åbn dokumentation",
    "Send mode" : "Tilstand for afsendelse",
    "Encryption" : "Kryptering",
    "From address" : "Fra adresse",
    "mail" : "mail",
    "Authentication method" : "Godkendelsesmetode",
    "Authentication required" : "Godkendelse påkrævet",
    "Server address" : "Serveradresse",
    "Port" : "Port",
    "Credentials" : "Brugeroplysninger",
    "SMTP Username" : "SMTP Brugernavn",
    "SMTP Password" : "SMTP Kodeord",
    "Test email settings" : "Test e-mail-indstillinger",
    "Send email" : "Send e-mail",
    "Security & setup warnings" : "Advarsler om sikkerhed og opsætning",
    "All checks passed." : "Alle tjek blev bestået.",
    "Version" : "Version",
    "Two-Factor Authentication" : "To-faktor godkendelse",
    "Server-side encryption" : "Kryptering på serversiden",
    "Enable server-side encryption" : "Slå kryptering til på serversiden",
    "Please read carefully before activating server-side encryption: " : "Læs venligst dette omhyggeligt, før der aktivere kryptering på serversiden:",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Kryptering alene garanterer ikke systemets sikkerhed. I dokumentationen er der mere information om hvordan krypteringsappen virker, og kan bruges.",
    "Be aware that encryption always increases the file size." : "Vær opmærksom på at kryptering altid øger filstørrelsen.",
    "This is the final warning: Do you really want to enable encryption?" : "Dette er den sidste advarsel: Sikker på at du vil slå kryptering til?",
    "Enable encryption" : "Slå kryptering til",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Der er ikke indlæst et krypteringsmodul - slå venligst et krypteringsmodul til i app-menuen.",
    "Select default encryption module:" : "Vælg standardmodulet til kryptering:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Du skal immigrere dine krypteringsnøgler fra den gamle kryptering (ownCloud <= 8.0) til den nye af slagsen. Slå venligst \"Standardmodul til kryptering\" til, og kør \"occ encryption:migrate\"",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Du skal immigrere dine krypteringsnøgler fra den gamle kryptering (ownCloud <= 8.0) til den nye af slagsen.",
    "Start migration" : "Påbegynd immigrering",
    "Execute one task with each page loaded" : "Udføre en opgave med hver side indlæsning",
    "Sharing" : "Deling",
    "Allow apps to use the Share API" : "Tillad apps til at bruge Share API",
    "Allow users to share via link" : "Tillad brugere at dele via link",
    "Allow public uploads" : "Tillad offentlig upload",
    "Always ask for a password" : "Spørg altid efter kodeord",
    "Enforce password protection" : "Gennemtving beskyttelse med kodeord",
    "Set default expiration date" : "Vælg standard udløbsdato",
    "Expire after " : "Udløber efter",
    "days" : "dage",
    "Enforce expiration date" : "Påtving udløbsdato",
    "Allow resharing" : "Tillad videredeling",
    "Allow sharing with groups" : "Tillad deling med grupper",
    "Restrict users to only share with users in their groups" : "Begræns brugere til kun at dele med brugere i deres egen gruppe",
    "Exclude groups from sharing" : "Ekskluder grupper fra at dele",
    "These groups will still be able to receive shares, but not to initiate them." : "Disse grupper vil stadig kunne modtage delefiler, men ikke skabe dem.",
    "Personal" : "Personligt",
    "Administration" : "Administration",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Udviklet af {communityopen}Nextcloud fællesskabet{linkclose}, {githubopen}kildekoden{linkclose} er udgivet med {licenseopen}AGPL{linkclose} licensen.",
    "Like our Facebook page" : "Følg os på Facebook",
    "Follow us on Twitter" : "Følg os på Twitter",
    "Follow us on Mastodon" : "Følg os på Mastodon",
    "Check out our blog" : "Besøg vores blog",
    "Subscribe to our newsletter" : "Abonner på vores nyhedsbrev",
    "Profile picture" : "Profilbillede",
    "Upload new" : "Upload nyt",
    "Select from Files" : "Vælg fra filer",
    "Remove image" : "Fjern billede",
    "png or jpg, max. 20 MB" : "png eller jpg, max. 20 MB",
    "Picture provided by original account" : "Billede leveret af den oprindelige konto",
    "Cancel" : "Annuller",
    "Choose as profile picture" : "Vælg et profilbillede",
    "Details" : "Detaljer",
    "You are a member of the following groups:" : "Du er medlem af følgende grupper:",
    "You are using <strong>%s</strong>" : "Du bruger <strong>%s</strong>",
    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Du bruger <strong>%1$s</strong> af <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
    "Full name" : "Fulde navn",
    "No display name set" : "Der er ikke angivet skærmnavn",
    "Your email address" : "Din e-mailadresse",
    "No email address set" : "Der er ikke angivet e-mailadresse",
    "For password reset and notifications" : "Til nulstilling af adgangskoder og meddelelser",
    "Phone number" : "Telefon nummer",
    "Your phone number" : "Dit telefon nummer",
    "Address" : "Adresse",
    "Your postal address" : "Dit Postnummer",
    "Website" : "Hjemmeside",
    "It can take up to 24 hours before the account is displayed as verified." : "Det kan tage op til 24 timer, før kontoen vises som verificeret.",
    "Link https://…" : "Link https://…",
    "Twitter" : "Twitter",
    "Twitter handle @…" : "Twitter handle @…",
    "Help translate" : "Hjælp med oversættelsen",
    "Current password" : "Nuværende adgangskode",
    "Change password" : "Skift kodeord",
    "Store credentials" : "Gem brugeroplysninger"
},
"nplurals=2; plural=(n != 1);");
